@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: MozRegisterComponents.cpp 7808 2007-12-23 22:38:56Z chpe $
+ *  $Id: MozRegisterComponents.cpp 8228 2008-05-18 21:50:08Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -44,6 +44,7 @@
 
 #ifdef HAVE_GECKO_1_9
 #include <nsIClassInfoImpl.h>
+#include <nsXULAppAPI.h>
 #endif
 
 #ifdef HAVE_MOZILLA_PSM
@@ -77,6 +78,10 @@
 #include "GeckoFormSigningDialog.h"
 #endif
 
+#ifdef HAVE_GECKO_1_9
+#include "EphyXULAppInfo.h"
+#endif
+
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutModule)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyPromptService)
@@ -104,7 +109,9 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoFormSigningDialog)
 #endif
 
-#define XPINSTALL_CONTRACTID NS_CONTENT_HANDLER_CONTRACTID_PREFIX "application/x-xpinstall"
+#ifdef HAVE_GECKO_1_9
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphyXULAppInfo)
+#endif
 
 /* class information */ 
 NS_DECL_CLASSINFO(EphySidebar)
@@ -112,6 +119,14 @@ NS_DECL_CLASSINFO(EphySidebar)
 /* FIXME: uninstall XPI handler */
 
 static const nsModuleComponentInfo sAppComps[] = {
+#ifdef HAVE_GECKO_1_9
+         {
+                EPHY_XUL_APP_INFO_CLASSNAME,
+                EPHY_XUL_APP_INFO_CID,
+                XULAPPINFO_SERVICE_CONTRACTID,
+                EphyXULAppInfoConstructor
+        },
+#endif
 	{
 		MOZ_DOWNLOAD_CLASSNAME,
 		MOZ_DOWNLOAD_CID,
@@ -200,6 +215,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_GLOBALHISTORY2_CONTRACTID,
 		MozGlobalHistoryConstructor
 	},
+#ifdef HAVE_GECKO_1_9
+        {
+		EPHY_GLOBALHISTORY_CLASSNAME,
+		EPHY_GLOBALHISTORY_CID,
+		NS_DOWNLOADHISTORY_CONTRACTID,
+		MozGlobalHistoryConstructor
+        },
+#endif
 	{
 		GECKO_PRINT_SERVICE_CLASSNAME,
 		GECKO_PRINT_SERVICE_IID,
