@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-dbus.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-dbus.c 7927 2008-02-10 18:26:22Z xan $
  */
 
 #include "config.h"
@@ -77,7 +77,6 @@ enum
 static EphyDbus *ephy_dbus_instance;
 
 static guint signals[LAST_SIGNAL];
-static GObjectClass *parent_class;
 GQuark ephy_dbus_error_quark;
 
 /* Filter signals form session bus */
@@ -344,28 +343,7 @@ ephy_dbus_shutdown (EphyDbus *dbus)
 
 /* Class implementation */
 
-static void
-ephy_dbus_init (EphyDbus *dbus)
-{
-	dbus->priv = EPHY_DBUS_GET_PRIVATE (dbus);
-
-	LOG ("EphyDbus initialising");
-}
-
-static void
-ephy_dbus_finalize (GObject *object)
-{
-	EphyDbus *dbus = EPHY_DBUS (object);
-
-	/* Have to do this after the object's weak ref notifiers have
-	 * been called, see https://bugs.freedesktop.org/show_bug.cgi?id=5688
-	 */
-	ephy_dbus_shutdown (dbus);
-
-	LOG ("EphyDbus finalised");
-
-	parent_class->finalize (object);
-}
+G_DEFINE_TYPE (EphyDbus, ephy_dbus, G_TYPE_OBJECT)
 
 static void
 ephy_dbus_get_property (GObject *object,
@@ -394,13 +372,34 @@ ephy_dbus_set_property (GObject *object,
 	}
 }
 
+static void
+ephy_dbus_finalize (GObject *object)
+{
+	EphyDbus *dbus = EPHY_DBUS (object);
+
+	/* Have to do this after the object's weak ref notifiers have
+	 * been called, see https://bugs.freedesktop.org/show_bug.cgi?id=5688
+	 */
+	ephy_dbus_shutdown (dbus);
+
+	LOG ("EphyDbus finalised");
+
+	G_OBJECT_CLASS (ephy_dbus_parent_class)->finalize (object);
+}
+
+static void
+ephy_dbus_init (EphyDbus *dbus)
+{
+	dbus->priv = EPHY_DBUS_GET_PRIVATE (dbus);
+
+	LOG ("EphyDbus initialising");
+}
+
 static void
 ephy_dbus_class_init (EphyDbusClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->get_property = ephy_dbus_get_property;
 	object_class->set_property = ephy_dbus_set_property;
 	object_class->finalize = ephy_dbus_finalize;
@@ -439,34 +438,6 @@ ephy_dbus_class_init (EphyDbusClass *klass)
 	g_type_class_add_private (object_class, sizeof(EphyDbusPrivate));
 }
 
-GType
-ephy_dbus_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyDbusClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_dbus_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyDbus),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_dbus_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyDbus",
-					       &our_info, 0);
-	}
-
-	return type;
-}
-
 EphyDbus *
 ephy_dbus_get_default (void)
 {
