@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-window.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-window.h 7709 2007-11-16 23:32:41Z xan $
  */
 
 #ifndef EPHY_WINDOW_H
 #define EPHY_WINDOW_H
 
 #include "ephy-embed.h"
-#include "ephy-tab.h"
 
 #include <glib-object.h>
 #include <glib.h>
@@ -61,7 +60,7 @@ EphyWindow	 *ephy_window_new		  (void);
 EphyWindow	 *ephy_window_new_with_chrome	  (EphyEmbedChrome chrome,
 						   gboolean is_popup);
 
-void		  ephy_window_set_print_preview	  (EphyWindow *window,
+void		 _ephy_window_set_print_preview	  (EphyWindow *window,
 						   gboolean enabled);
 
 GObject		 *ephy_window_get_ui_manager	  (EphyWindow *window);
@@ -74,17 +73,6 @@ GtkWidget        *ephy_window_get_find_toolbar    (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_statusbar	  (EphyWindow *window);
 
-void		  ephy_window_add_tab		  (EphyWindow *window,
-						   EphyTab *tab,
-						   gint position,
-						   gboolean jump_to);
-
-void		  ephy_window_remove_tab	  (EphyWindow *window,
-						   EphyTab *tab);
-
-void		  ephy_window_jump_to_tab	  (EphyWindow *window,
-						   EphyTab *tab);
-
 void		  ephy_window_load_url		  (EphyWindow *window,
 						   const char *url);
 
@@ -93,14 +81,6 @@ void		  ephy_window_set_zoom		  (EphyWindow *window,
 
 void		  ephy_window_activate_location	  (EphyWindow *window);
 
-EphyTab		 *ephy_window_get_active_tab	  (EphyWindow *window);
-
-EphyEmbed	 *ephy_window_get_active_embed	  (EphyWindow *window);
-
-GList		 *ephy_window_get_tabs		  (EphyWindow *window);
-
-gboolean	  ephy_window_get_is_popup	  (EphyWindow *window);
-
 gboolean	  ephy_window_get_is_print_preview(EphyWindow *window);
 
 EphyEmbedEvent	 *ephy_window_get_context_event	  (EphyWindow *window);
